@@ -24,7 +24,7 @@
 #ifndef _GO_COMBO_PIXMAPS_H_
 #define _GO_COMBO_PIXMAPS_H_
 
-#include <gtk/gtktooltips.h>
+#include <gtk/gtkwidget.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
 
 G_BEGIN_DECLS
