@@ -74,7 +74,7 @@ gog_bubble_plot_pref (GogBubblePlot *bubble, GOCmdContext *cc)
 	char const *dir = go_plugin_get_dir_name (
 		go_plugins_get_plugin_by_id ("GOffice_plot_xy"));
 	char	 *path = g_build_filename (dir, "gog-bubble-prefs.glade", NULL);
-	GladeXML *gui = go_libglade_new (path, "gog_bubble_prefs", NULL, cc);
+	GladeXML *gui = go_libglade_new (path, "gog_bubble_prefs", GETTEXT_PACKAGE, cc);
 
 	g_free (path);
         if (gui == NULL)
@@ -103,7 +103,8 @@ gog_bubble_plot_pref (GogBubblePlot *bubble, GOCmdContext *cc)
 	g_signal_connect (G_OBJECT (w),
 		"toggled",
 		G_CALLBACK (cb_3d_changed), bubble);
-#warning "Hide 3d button while not supported"
+
+	/* TODO Add support for 3D bubbles. Hide the button for now. */
 	gtk_widget_hide (w);
 
 	w = glade_xml_get_widget (gui, "scale");
